@@ -1,12 +1,8 @@
 use testing::examples;
 
-// smoelius: In each use of `examples::test_fuzz` below, the `target` argument is arbitrary. To
-// have a version of `examples::test_fuzz` that takes no arguments for just these tests would be
-// more trouble than it is worth.
-
 #[test]
 fn build_no_instrumentation() {
-    examples::test_fuzz("assert", "assert::target")
+    examples::test_fuzz_all()
         .unwrap()
         .args(&["--no-run", "--no-instrumentation"])
         .assert()
@@ -15,7 +11,7 @@ fn build_no_instrumentation() {
 
 #[test]
 fn build() {
-    examples::test_fuzz("assert", "assert::target")
+    examples::test_fuzz_all()
         .unwrap()
         .args(&["--no-run"])
         .assert()
@@ -24,7 +20,7 @@ fn build() {
 
 #[test]
 fn build_pesistent() {
-    examples::test_fuzz("assert", "assert::target")
+    examples::test_fuzz_all()
         .unwrap()
         .args(&["--no-run", "--persistent"])
         .assert()
