@@ -3,21 +3,15 @@ use testing::examples;
 
 #[test]
 fn display_qwerty() {
-    display(
-        "qwerty",
-        "qwerty::test",
-        "qwerty::target",
-        "Args { data: \"asdfgh\" }",
-        "",
-    );
+    display("qwerty", "test", "target", "Args { data: \"asdfgh\" }", "");
 }
 
 #[test]
 fn display_debug_crash() {
     display(
         "debug",
-        "debug_crash::target_fuzz::auto_generate",
-        "debug_crash::target",
+        "crash::target_fuzz::auto_generate",
+        "crash::target",
         "",
         "Encountered a failure while not replaying. A buggy Debug implementation perhaps?",
     );
@@ -27,17 +21,17 @@ fn display_debug_crash() {
 fn display_debug_hang() {
     display(
         "debug",
-        "debug_hang::target_fuzz::auto_generate",
-        "debug_hang::target",
+        "hang::target_fuzz::auto_generate",
+        "hang::target",
         "",
         "Encountered a timeout while not replaying. A buggy Debug implementation perhaps?",
     );
 }
 
-fn display(name: &str, test: &str, target: &str, stdout: &str, stderr: &str) {
-    examples::test(name, test).unwrap().assert().success();
+fn display(krate: &str, test: &str, target: &str, stdout: &str, stderr: &str) {
+    examples::test(krate, test).unwrap().assert().success();
 
-    examples::test_fuzz(name, target)
+    examples::test_fuzz(krate, target)
         .unwrap()
         .args(&["--display-corpus"])
         .assert()
